<?php
namespace App\Exports;  
use App\Models\SupplierModel;
use Illuminate\Contracts\View\View;
use Maatwebsite\Excel\Concerns\FromView;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Concerns\WithDrawings;
use PhpOffice\PhpSpreadsheet\Worksheet\Drawing;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithCustomStartCell;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;
use PDF;

class PurchaseInvoiceVerificationExport implements FromView,WithDrawings,ShouldAutoSize,WithCustomStartCell,WithEvents
   {
	   protected $invoice_verification; 
		/**
		* @return \Illuminate\Support\Collection
		*/
	 function __construct($invoice_verification) {
        $this->invoice_verification = $invoice_verification;
       }
	   
   public function drawings()
     {
        $drawing = new Drawing();
        $drawing->setName('Logo');
        $drawing->setDescription('This is my logo');
        $drawing->setPath(public_path('elitesotlab.png'));
        $drawing->setHeight(87);
        $drawing->setCoordinates('A1'); 
		
        return $drawing;
    }
	
	public function startCell(): string
    {
        return 'A9'; 
    }
	
	 public function registerEvents(): array
    {
        return [
            AfterSheet::class=> function(AfterSheet $event) {
                $event-> sheet->mergeCells('A1:D5');
                   
                $event->sheet->getStyle('A6:H6')->applyFromArray ([ 
                    'font' => [
                        'name'      =>  'Calibri',
                        'size'      =>  13,
                        'bold'      =>  true,
                        'color' => ['argb' => '#000000'],
                    ],
					'fill' => [
                        'fillType' => \PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID,
                        'startColor' => [
                            'rgb' => 'dff0d8',
                         ],           
                    ] 
				]); 
				
				$event->sheet->getStyle('A10:H10')->applyFromArray ([ 
                    'font' => [
                        'name'      =>  'Calibri',
                        'size'      =>  13,
                        'bold'      =>  true,
                        'color' => ['argb' => '#000000'],
                    ],
					'fill' => [
                        'fillType' => \PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID,
                        'startColor' => [
                            'rgb' => 'dff0d8',
                         ],           
                    ] 
				]); 
	 }
        ];
    }
	  
    public function view(): View
    { 
		$get_data_header = DB::table('tbl_invoice_verification_header')
		   ->leftJoin('tbl_supplier', 'tbl_invoice_verification_header.supplier_id', '=', 'tbl_supplier.id')
		   ->leftJoin('tbl_purchase_order_header', 'tbl_invoice_verification_header.purchase_order_id', '=', 'tbl_purchase_order_header.id')
		   ->leftJoin('tbl_good_receipt_note_header', 'tbl_invoice_verification_header.grn_id', '=', 'tbl_good_receipt_note_header.id')
		   ->select('tbl_supplier.supplier_code','tbl_supplier.supplier_name','tbl_purchase_order_header.purchase_order_number','tbl_good_receipt_note_header.grn_code','tbl_invoice_verification_header.invoice_code','tbl_invoice_verification_header.total_invoice_value')
		   ->where('tbl_invoice_verification_header.id','=',$this->invoice_verification)
		   ->get()->all();

         $get_data_details =DB::table('tbl_invoice_verification_details')
		  ->leftJoin('tbl_material_master', 'tbl_invoice_verification_details.material_id', '=', 'tbl_material_master.id')
		  ->leftJoin('tbl_unit_of_measurement', 'tbl_invoice_verification_details.uom', '=', 'tbl_unit_of_measurement.id')
          ->select('tbl_material_master.material_name', 'tbl_material_master.material_code as mat_code','tbl_unit_of_measurement.unit_notation','tbl_invoice_verification_details.quantity','tbl_invoice_verification_details.unit_price','tbl_invoice_verification_details.vat','tbl_invoice_verification_details.net_amount','tbl_invoice_verification_details.total','tbl_invoice_verification_details.discount')
		  ->where('tbl_invoice_verification_details.header_id', '=', $this->invoice_verification)->get()->all();
		  
        return view('export.purchase_invoice_verificatione_xport', ['header' => $get_data_header], ['details' => $get_data_details] );
    } 
	 
 }