<?php
namespace App\Exports;
use App\Models\SupplierModel;
use Illuminate\Contracts\View\View;
use Maatwebsite\Excel\Concerns\FromView;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Concerns\WithDrawings;
use PhpOffice\PhpSpreadsheet\Worksheet\Drawing;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithCustomStartCell;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;

class PurchaseOrderReportExportPdf implements FromView,ShouldAutoSize,WithCustomStartCell,WithEvents
   {
	   protected $purchase_order;
	 
    /**
    * @return \Illuminate\Support\Collection
    */
	 function __construct($purchase_order) {
        $this->purchase_order = $purchase_order;
       }
	   
	
	
	public function startCell(): string
    {
        return 'A6';

    }
	
	 public function registerEvents(): array
    {
        return [
            AfterSheet::class=> function(AfterSheet $event) {
               
                   
                $event->sheet->getStyle('A6:K6')->applyFromArray ([
				
                    'font' => [
                        'name'      =>  'Calibri',
                        'size'      =>  13,
                        'bold'      =>  true,
                        'color' => ['argb' => '#000011'],
                    ],
					
				 
				    
				]); 
				
				$event->sheet->getStyle('A10:K10')->applyFromArray ([
				
                    'font' => [
                        'name'      =>  'Calibri',
                        'size'      =>  13,
                        'bold'      =>  true,
                        'color' => ['argb' => '#000000'],
                    ],
				]);
				 
            
	 }
        ];
    }
	

	   
    public function view(): View
    {
		
		$get_data1 = DB::table('tbl_purchase_order_header')
		   ->leftJoin('tbl_supplier', 'tbl_purchase_order_header.supplier_id', '=', 'tbl_supplier.id')
		   ->select('tbl_supplier.supplier_code','tbl_supplier.supplier_name','tbl_purchase_order_header.purchase_order_number','tbl_purchase_order_header.delivery_date','tbl_purchase_order_header.total_invoice_value')
		   ->where('tbl_purchase_order_header.id','=',$this->purchase_order)
		   ->get()->all();

         $get_data_details =DB::table('tbl_purchase_order_details')
		  ->leftJoin('tbl_material_master', 'tbl_purchase_order_details.material_id', '=', 'tbl_material_master.id')
		  ->leftJoin('tbl_unit_of_measurement', 'tbl_purchase_order_details.uom', '=', 'tbl_unit_of_measurement.id')
          ->select('tbl_material_master.material_name', 'tbl_material_master.material_code as mat_code','tbl_unit_of_measurement.unit_notation','tbl_purchase_order_details.quantity','tbl_purchase_order_details.unite_price','tbl_purchase_order_details.vat','tbl_purchase_order_details.net_amount','tbl_purchase_order_details.total','tbl_purchase_order_details.discount')
		  ->where('tbl_purchase_order_details.header_id', '=', $this->purchase_order)->get()->all();
		  
        return view('export.pdf.purchase_order_export_pdf', 
		                  ['header' => $get_data1],
		                  ['details' => $get_data_details]
						  
		            );
    } 
	
	
	
    
	
 }
