<?php
namespace App\Exports;
use App\Models\SupplierModel;
use Illuminate\Contracts\View\View;
use Maatwebsite\Excel\Concerns\FromView;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Concerns\WithDrawings;
use PhpOffice\PhpSpreadsheet\Worksheet\Drawing;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithCustomStartCell;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;

class RouteOrderExport implements FromView,WithDrawings,ShouldAutoSize,WithCustomStartCell,WithEvents
   {
	   protected $route_order;
	 
    /**
    * @return \Illuminate\Support\Collection
    */
	 function __construct($route_order) {
        $this->route_order = $route_order;
       }
	   
	 public function drawings()
    {
        $drawing = new Drawing();
        $drawing->setName('Logo');
        $drawing->setDescription('This is my logo');
        $drawing->setPath(public_path('elitesotlab.png'));
        $drawing->setHeight(87);
        $drawing->setCoordinates('A1');

        return $drawing;
    }
	
	public function startCell(): string
    {
        return 'A6';

    }
	
	 public function registerEvents(): array
    {
        return [
            AfterSheet::class=> function(AfterSheet $event) {
                $event-> sheet->mergeCells('A1:E5');
                   
                $event->sheet->getStyle('A6:H6')->applyFromArray ([
				
                    'font' => [
                        'name'      =>  'Calibri',
                        'size'      =>  13,
                        'bold'      =>  true,
                        'color' => ['argb' => '#000000'],
                    ],
					'fill' => [
                        'fillType' => \PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID,
                        'startColor' => [
                            'rgb' => 'dff0d8',
                         ],           
                    ]
				 
				    
				]); 
				
				$event->sheet->getStyle('A10:H10')->applyFromArray ([
				
                    'font' => [
                        'name'      =>  'Calibri',
                        'size'      =>  13,
                        'bold'      =>  true,
                        'color' => ['argb' => '#000000'],
                    ],
					'fill' => [
                        'fillType' => \PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID,
                        'startColor' => [
                            'rgb' => 'dff0d8',
                         ],           
                    ]
				 
				    
				]);
				 
            
	 }
        ];
    }
	

	   
    public function view(): View
    {
		

		$get_data1 =DB::table('tbl_route_order_header')
		->leftJoin('tbl_trading_center', 'tbl_route_order_header.trading_center_id', '=', 'tbl_trading_center.id')
		->leftJoin('tbl_route', 'tbl_route_order_header.route_id', '=', 'tbl_route.id')
		->leftJoin('tbl_customer', 'tbl_route_order_header.customer_id', '=', 'tbl_customer.id')
		->leftJoin('tbl_warehouse', 'tbl_route_order_header.warehouse_id', '=', 'tbl_warehouse.id')
		->leftJoin('tbl_currency_type', 'tbl_route_order_header.currency_id', '=', 'tbl_currency_type.id')
		->leftJoin('tbl_salesman', 'tbl_route_order_header.salesman_id', '=', 'tbl_salesman.id')
	
		 ->select('tbl_route_order_header.*', 'tbl_trading_center.trading_name', 'tbl_trading_center.trading_center_code', 'tbl_route.route_name','tbl_route.route_code','tbl_customer.customer_name','tbl_customer.customer_code','tbl_warehouse.warehouse_name','tbl_warehouse.warehouse_code','tbl_salesman.salesman_name','tbl_salesman.salesman_code','tbl_currency_type.currency_notation')
         ->where('tbl_route_order_header.id', '=',$this->route_order)->get()->first();
		 

		 $get_data_details =DB::table('tbl_route_order_details')
		 

		  ->leftJoin('tbl_material_master', 'tbl_route_order_details.material_id', '=', 'tbl_material_master.id')
		  ->leftJoin('tbl_unit_of_measurement', 'tbl_route_order_details.uom_id', '=', 'tbl_unit_of_measurement.id')
  
		  ->select('tbl_route_order_details.*','tbl_material_master.material_name', 'tbl_material_master.material_code as mat_code','tbl_unit_of_measurement.unit_notation')->where('tbl_route_order_details.header_id', '=',$this->route_order)->get()->all();
  
		  
        return view('export.route_order_export', 
		                  ['header' => $get_data1],
		                  ['details' => $get_data_details]
						  
		            );
    } 
	
	
	
    
	
 }
