<?php
namespace App\Exports;
use App\Models\SupplierModel;
use Illuminate\Contracts\View\View;
use Maatwebsite\Excel\Concerns\FromView;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Concerns\WithDrawings;
use PhpOffice\PhpSpreadsheet\Worksheet\Drawing;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use Maatwebsite\Excel\Concerns\WithCustomStartCell;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Events\AfterSheet;

class SalesManLoadListExport implements FromView,WithDrawings,ShouldAutoSize,WithCustomStartCell,WithEvents
   {
	   protected $salesman_load;
	 
    /**
    * @return \Illuminate\Support\Collection
    */
	 function __construct($salesman_load) {
        $this->salesman_load = $salesman_load;
       }
	   
	 public function drawings()
    {
        $drawing = new Drawing();
        $drawing->setName('Logo');
        $drawing->setDescription('This is my logo');
        $drawing->setPath(public_path('elitesotlab.png'));
        $drawing->setHeight(87);
        $drawing->setCoordinates('A1');

        return $drawing;
    }
	
	public function startCell(): string
    {
        return 'A6';

    }
	
	 public function registerEvents(): array
    {
        return [
            AfterSheet::class=> function(AfterSheet $event) {
                $event-> sheet->mergeCells('A1:E5');
                   
                $event->sheet->getStyle('A6:E6')->applyFromArray ([
				
                    'font' => [
                        'name'      =>  'Calibri',
                        'size'      =>  13,
                        'bold'      =>  true,
                        'color' => ['argb' => '#000000'],
                    ],
					'fill' => [
                        'fillType' => \PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID,
                        'startColor' => [
                            'rgb' => 'dff0d8',
                         ],           
                    ]
				 
				    
				]); 
				
				$event->sheet->getStyle('A10:E10')->applyFromArray ([
				
                    'font' => [
                        'name'      =>  'Calibri',
                        'size'      =>  13,
                        'bold'      =>  true,
                        'color' => ['argb' => '#000000'],
                    ],
					'fill' => [
                        'fillType' => \PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID,
                        'startColor' => [
                            'rgb' => 'dff0d8',
                         ],           
                    ]
				 
				    
				]);
				 
            
	 }
        ];
    }



    public function view(): View
    { 
			$get_data =DB::table('tbl_route_salesmanload_header')
		->leftJoin('tbl_route', 'tbl_route_salesmanload_header.route_id', '=', 'tbl_route.id')
		->leftJoin('tbl_salesman', 'tbl_route_salesmanload_header.salesman_id', '=', 'tbl_salesman.id')
		->leftJoin('tbl_currency_type', 'tbl_route_salesmanload_header.currency', '=', 'tbl_currency_type.id')
	  
		->select('tbl_route_salesmanload_header.*','tbl_route.route_code','tbl_route.route_name','tbl_salesman.salesman_name','tbl_salesman.salesman_code','tbl_currency_type.currency_notation','tbl_route_salesmanload_header.total_load_value')
		->where('tbl_route_salesmanload_header.id', '=', $this->salesman_load)->get();

		$get_data_details =DB::table('tbl_route_salesmanload_details') 
 
		->leftJoin('tbl_material_master', 'tbl_route_salesmanload_details.material_id', '=', 'tbl_material_master.id')
		->leftJoin('tbl_unit_of_measurement', 'tbl_route_salesmanload_details.uom_id', '=', 'tbl_unit_of_measurement.id')

		->select('tbl_route_salesmanload_details.*','tbl_material_master.material_name','tbl_material_master.material_code','tbl_unit_of_measurement.unit_notation')
		->where('tbl_route_salesmanload_details.header_id', '=', $this->salesman_load)->get()->all();	  
		
        return view('export.salesman_load_export', 
		                  ['header' => $get_data],
		                  ['details' => $get_data_details]
						  
		            );
    } 
	
 }
